@@ -529,6 +529,6 @@ XHr|HZ[&|>IV`-7qOc<#VCIY@kz]#\"AX\"\"\"\"yRLhb^\"YT=OrvUDD\$]
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fp-wien/assets/logo.png", "/var/www/html/staging-demo/themes/fp-wien/assets/logo.png");
+        return new Source("", "@themes/fp-wien/assets/logo.png", "/var/www/mautic-ktn/themes/fp-wien/assets/logo.png");
     }
 }
